@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.43 2003/12/05 11:28:50 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.47 2003/12/08 04:27:10 fuyu Exp $
  */
 
 #include "config.h"
@@ -169,7 +169,7 @@ typedef struct _RendererContext
   GtkTextTag *response_paragraph_tag;
   GtkTextTag *bold_tag;
 
-#if defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA)
+#if defined(ENABLE_ONIGURUMA)
   regex_t comma_separated_link_pattern;
   regex_t informal_link_pattern;
 #endif
@@ -857,7 +857,7 @@ popup_context_free(PopupContext *popup_context)
       popup_context->renderer_context.link_text_buffer = NULL;
     }
 
-#if defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA)
+#if defined(ENABLE_ONIGURUMA)
   /* "\357\274\214\343\200\201"  "" UTF-8ɽ */
   regfree(&popup_context->renderer_context.comma_separated_link_pattern);
   regfree(&popup_context->renderer_context.informal_link_pattern);
@@ -931,7 +931,7 @@ ensure_popup_context(BBSThreadView *parent, OchushaApplication *application)
 			  (GDestroyNotify)popup_context_free);
 
 
-#if defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA)
+#if defined(ENABLE_ONIGURUMA)
   /* "\357\274\214\343\200\201"  "" UTF-8ɽ */
   if (regcomp(&renderer_context->comma_separated_link_pattern,
 	      "^[,\357\274\214\343\200\201][ ]*([1-9][0-9]*)(-[1-9][0-9]*)?",
@@ -1050,6 +1050,42 @@ show_mailto(OchushaApplication *application, OchushaBBSThread *thread)
 }
 
 
+typedef struct _ScrollToMarkArgs
+{
+  BBSThreadView *view;
+  BBSThreadGUIInfo *info;
+} ScrollToMarkArgs;
+
+
+gboolean
+scroll_to_mark_on_idle(ScrollToMarkArgs *args)
+{
+  gdk_threads_enter();
+  if (args->info->next_mark != NULL)
+    {
+      bbs_thread_view_scroll_to_mark(args->view, args->info->next_mark);
+      args->info->next_mark = NULL;
+      args->info->scroller_id = 0;
+    }
+  gdk_threads_leave();
+  return FALSE;
+}
+
+
+static void
+save_initial_thread_view_position(BBSThreadView *view, BBSThreadGUIInfo *info,
+				  GtkTextMark *mark)
+{
+  ScrollToMarkArgs *args = G_NEW0(ScrollToMarkArgs, 1);
+  info->next_mark = mark;
+  args->view = view;
+  args->info = info;
+  info->scroller_id = g_idle_add_full(G_PRIORITY_DEFAULT_IDLE,
+				      (GSourceFunc)scroll_to_mark_on_idle,
+				      args, (GDestroyNotify)g_free);
+}
+
+
 static void
 render_bbs_thread(WorkerThread *employee, gpointer args)
 {
@@ -1097,7 +1133,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       bbs_thread_view_get_tag_by_name(job_args->view, "bold"),
   };
 
-#if defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA)
+#if defined(ENABLE_ONIGURUMA)
   /* "\357\274\214\343\200\201\357\274\235"  "" UTF-8ɽ */
   if (regcomp(&context.comma_separated_link_pattern,
 	      "^[,=\357\274\214\343\200\201\357\274\235][ ]*([1-9][0-9]*)(-[1-9][0-9]*)?",
@@ -1161,8 +1197,6 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       if (index > 0
 	  && info->offsets_length > index && info->offsets[index] != 0)
 	{
-	  bbs_thread_view_scroll_to_offset(job_args->view,
-					   info->offsets[index]);
 	  info->last_read
 	    = bbs_thread_view_create_mark_at_offset(job_args->view,
 						    info->offsets[index]);
@@ -1170,7 +1204,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       else
 	info->last_read = bbs_thread_view_create_mark(job_args->view);
 
-      info->next_mark = info->last_read;
+      save_initial_thread_view_position(job_args->view, info, info->last_read);
 #if DEBUG_GUI
       fprintf(stderr, "create mark at the tail response.\n");
 #endif
@@ -1179,6 +1213,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
   ochusha_bbs_thread_parse_responses(thread, buffer,
 				     job_args->start,
 				     job_args->number_of_responses,
+				     FALSE,
 				     start_thread_rendering,
 				     render_response,
 				     render_broken_response,
@@ -1216,7 +1251,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
   }
   BBS_THREAD_UI_UNLOCK;
 
-#if defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA)
+#if defined(ENABLE_ONIGURUMA)
   /* "\357\274\214\343\200\201"  "" UTF-8ɽ */
   regfree(&context.comma_separated_link_pattern);
   regfree(&context.informal_link_pattern);
@@ -1247,8 +1282,7 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
       /* ɤॹξ祿ȥߤˤΤǤ˥ޡդ롣*/
       info = ensure_bbs_thread_info(context->thread);
       info->last_read = bbs_thread_view_create_mark(view);
-      info->next_mark = info->last_read;
-      bbs_thread_view_scroll_to_mark(view, info->last_read);
+      save_initial_thread_view_position(view, info, info->last_read);
     }
   else
     info = NULL;
@@ -1308,10 +1342,7 @@ render_response(OchushaBBSThread *thread, gint number,
     {
       /* ɥ쥹*/
       info->last_read = bbs_thread_view_create_mark(view);
-      info->next_mark = info->last_read;
-      gdk_threads_enter();
-      bbs_thread_view_scroll_to_mark(view, info->last_read);
-      gdk_threads_leave();
+      save_initial_thread_view_position(view, info, info->last_read);
     }
 
   if (thread->number_of_responses_read < number)
@@ -1426,12 +1457,6 @@ render_response(OchushaBBSThread *thread, gint number,
 
   bbs_thread_view_append_text(view, "\n", 1);
 
-  if (number == context->last_read_number)
-    {
-      /* ɥ쥹*/
-      bbs_thread_view_scroll_to_mark(view, info->last_read);
-    }
-
   gdk_threads_leave();
 
   return TRUE;
@@ -1468,10 +1493,7 @@ render_broken_response(OchushaBBSThread *thread, gint number,
     {
       /* ɥ쥹*/
       info->last_read = bbs_thread_view_create_mark(view);
-      info->next_mark = info->last_read;
-      gdk_threads_enter();
-      bbs_thread_view_scroll_to_mark(view, info->last_read);
-      gdk_threads_leave();
+      save_initial_thread_view_position(view, info, info->last_read);
     }
 
   if (thread->number_of_responses_read < number)
@@ -1541,10 +1563,7 @@ end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
        *       ХåեκǸ˥ޡĤƤ
        */
       info->last_read = bbs_thread_view_create_mark(view);
-      info->next_mark = info->last_read;
-      gdk_threads_enter();
-      bbs_thread_view_scroll_to_mark(view, info->last_read);
-      gdk_threads_leave();
+      save_initial_thread_view_position(view, info, info->last_read);
 #if DEBUG_GUI
       fprintf(stderr, "end_thread_rendering: What's happen?\n");
 #endif
@@ -1561,13 +1580,24 @@ end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
 static void
 process_link(RendererContext *context)
 {
+  gchar *text;
   if (context->link == NULL)
     return;
 
-  bbs_thread_view_append_text_as_link(context->view,
-				      context->link_text_buffer,
-				      context->link_text_length,
-				      context->link);
+  text = simple_string_canon(context->link_text_buffer,
+			     context->link_text_length,
+			     NULL, NULL);
+
+  if (text != NULL)
+    bbs_thread_view_append_text_as_link(context->view, text, -1,
+					context->link);
+  else
+    bbs_thread_view_append_text_as_link(context->view,
+					context->link_text_buffer,
+					context->link_text_length,
+					context->link);
+  if (text != NULL)
+    G_FREE(text);
   G_FREE(context->link);
   context->link = NULL;
   context->last_text_is_link = TRUE;
@@ -1674,7 +1704,7 @@ characters_cb(void *user_data, const char *ch, int len)
 
   if (context->link == NULL)
     {
-#if defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA)
+#if defined(ENABLE_ONIGURUMA)
       if (context->application->analyze_informal_links)
 	{
 	  regmatch_t match[3];
@@ -1881,7 +1911,7 @@ characters_cb(void *user_data, const char *ch, int len)
 	}
 #else
       bbs_thread_view_append_text(context->view, ch, len);
-#endif	/* defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA) */
+#endif	/* defined(ENABLE_ONIGURUMA) */
       return;
     }
 
@@ -2183,6 +2213,7 @@ render_popup_response(PopupContext *popup_context,
   gdk_threads_leave();
   ochusha_bbs_thread_parse_responses(thread, buffer,
 				     response_from - 1, num_responses,
+				     TRUE,
 				     NULL, render_response,
 				     render_broken_response, NULL,
 				     &popup_context->renderer_context);
