@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.h,v 1.7 2003/11/23 17:07:26 fuyu Exp $
+ * $Id: boardlist_view.h,v 1.8 2003/12/03 07:53:11 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_VIEW_H_
@@ -60,6 +60,8 @@ struct _BoardlistView
   gdouble last_event_x;
   gdouble last_event_y;
   guint last_event_button;
+
+  gboolean default_open_in_tab;
 };
 
 
@@ -102,6 +104,10 @@ GtkWidget *boardlist_view_new(void);
 void boardlist_view_open(BoardlistView *view, GSList *category_list,
 			 gboolean really_hide_hidden_items);
 
+gboolean boardlist_view_get_default_open_in_tab(BoardlistView *view);
+void boardlist_view_set_default_open_in_tab(BoardlistView *view,
+					    gboolean default_open_in_tab);
+
 void boardlist_view_expand_category(BoardlistView *view,
 				    OchushaBoardCategory *category);
 void boardlist_view_collapse_category(BoardlistView *view,
