@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.65 2003/12/05 12:42:51 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.67 2003/12/08 04:27:10 fuyu Exp $
  */
 
 #include "config.h"
@@ -441,7 +441,7 @@ title_match_func(const gchar *title, ThreadlistSearchQueryData *search_data)
 #endif
     }
 
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
   if (search_data->use_regexp)
     {
       if (search_data->regexp_available)
@@ -1581,6 +1581,24 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
       GtkWidget *thread_view = gtk_bin_get_child(GTK_BIN(item_view));
       if (application->last_search_target_widget == thread_view)
 	application->last_search_target_widget = NULL;
+
+      if (paned_notebook->number_of_items_shown == 1)
+	{
+	  if (gtk_widget_is_focus(thread_view))
+	    {
+	      GtkWidget *threadlist_view
+		= gtk_bin_get_child(GTK_BIN(paned_notebook->selector));
+	      gtk_widget_grab_focus(GTK_WIDGET(threadlist_view));
+	    }
+	}
+    }
+
+  info->last_read = NULL;
+  info->next_mark = NULL;
+  if (info->scroller_id != 0)
+    {
+      g_source_remove(info->scroller_id);
+      info->scroller_id = 0;
     }
 }
 
@@ -1589,7 +1607,6 @@ static void
 item_view_closed_cb(PanedNotebook *paned_notebook, OchushaBBSThread *thread,
 		    GtkWidget *item_view, OchushaApplication *application)
 {
-  BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
   /* ΥåɽĤ줿 */
 #if DEBUG_GUI_MOST
   fprintf(stderr, "closed: thread=%p, item_view=%p\n", thread, item_view);
@@ -1597,8 +1614,6 @@ item_view_closed_cb(PanedNotebook *paned_notebook, OchushaBBSThread *thread,
 
   delayed_g_object_unref(G_OBJECT(item_view));
 
-  info->last_read = NULL;
-  info->next_mark = NULL;
   free_response_source_buffer(thread, NULL);
 }
 
