@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.h,v 1.17 2003/12/04 07:32:17 fuyu Exp $
+ * $Id: bulletin_board_ui.h,v 1.18 2003/12/07 16:57:58 fuyu Exp $
  */
 
 #ifndef _BULLETIN_BOARD_UI_H_
@@ -41,26 +41,11 @@
 
 #include <gtk/gtk.h>
 
-#if ENABLE_REGEXP
-# if HAVE_ONIGURUMA
-#  if HAVE_ONIG_ONIGPOSIX_H
-#    include <onig/onigposix.h>
-#  elif HAVE_ONIGPOSIX_H
-#    include <onigposix.h>
-#  else
-#    error "Use of oniguruma without onig/onigposix.h header isn't considered."
-#  endif
+#if ENABLE_ONIGURUMA
+# if HAVE_ONIG_ONIGPOSIX_H
+#  include <onig/onigposix.h>
 # else
-#  if HAVE_POSIX_REGEX
-#    if HAVE_SYS_TYPES_H
-#      include <sys/types.h>
-#    endif
-#    if HAVE_REGEX_H
-#      include <regex.h>
-#    else
-#      warning "I don't know suitable header file of your posix regex library."
-#    endif
-#  endif
+#  include <onigposix.h>
 # endif
 #endif
 
@@ -100,7 +85,7 @@ typedef struct _ThreadlistSearchQueryData
   gint direction;
   ThreadlistView *last_view;
 
-#if ENABLE_REGEXP
+#if ENABLE_ONIGURUMA
   regex_t regexp;
   gboolean regexp_available;
 #endif
