@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.8 2003/12/05 08:45:58 fuyu Exp $
+ * $Id: main.c,v 1.9 2003/12/06 02:38:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -61,12 +61,16 @@ main(int argc, char *argv[])
 
   application = G_NEW0(OchushaApplication, 1);
   ochusha_config_prepare_home(&application->config);
+
+  gtk_rc_parse_string("gtk-toolbar-style = icons\n"
+		      "gtk-toolbar-icon-size = small-toolbar\n");
   gtk_rc_add_default_file(PKGDATADIR "/" OCHUSHA_GTKRC);
 
   g_thread_init(NULL);
   gdk_threads_init();
   gtk_set_locale();
   gtk_init(&argc, &argv);
+
   bindtextdomain(PACKAGE_NAME, LOCALEDIR);
   textdomain(PACKAGE_NAME);
 
