@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: text_search_window.c,v 1.7 2003/06/07 14:35:31 fuyu Exp $
+ * $Id: text_search_window.c,v 1.8 2003/12/07 16:57:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -306,7 +306,7 @@ text_search_window_init(TextSearchWindow *window)
 
   window->use_regexp_button
     = GTK_TOGGLE_BUTTON(gtk_check_button_new_with_label(_("Regular expression")));
-#if !ENABLE_REGEXP
+#if !ENABLE_ONIGURUMA
   gtk_widget_set_sensitive(GTK_WIDGET(window->use_regexp_button), FALSE);
 #endif
   g_signal_connect_swapped(window->use_regexp_button, "toggled",
