@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: htmlutils.c,v 1.8 2003/11/26 12:59:36 fuyu Exp $
+ * $Id: htmlutils.c,v 1.9 2003/12/05 15:50:55 fuyu Exp $
  */
 
 #include "config.h"
@@ -444,27 +444,13 @@ default_entity_ref_handler(ElementHandler *handler, void *context,
 
 
 #define DEFAULT_BUFFER_SIZE	4096
-/*
- * (SAX)HTMLѡ
- * textĹlenʸHTMLʸȻפäƲϤΤΤentity
- * ȤΤ褦ʤΡơʳʸΤ줾ˤĤơб
- * callbackƤӽФ
- *
- * callbackNULLξ硢ʲ˼褦ʥǥեȤư򤹤롣
- * startElement: ̵
- * endElement: ̵
- * entity: ơ֥ʸѴcharactersϥɥƤ֡
- * characters: ̵
- *
- * converter0ξ硢callbackƤiconvȤäʸencoding
- * Ѵ롣converter0ξ硢textUTF-8 encodingǤȲꤹ롣
- *
- * '<'⤷'&'줿ˤؤ餺б'>'';'ʤä硢
- * '<'⤷'&'ľޤǤǥѡ󥰤ߤΥݥ󥿤֤
- *ʳξˤNULL֤
- */
-const char *
-parse_text(ElementHandler *handler, void *context, const char *text, int len)
+
+
+
+
+static const char *
+parse_text_internal(ElementHandler *handler, void *context, const char *text,
+		    int len, gboolean fake_anchor)
 {
   gchar default_buffer[DEFAULT_BUFFER_SIZE];
   size_t buffer_size = DEFAULT_BUFFER_SIZE;
@@ -488,7 +474,7 @@ parse_text(ElementHandler *handler, void *context, const char *text, int len)
       chr_len = (tmp_pos == NULL) ? rest_of_text : tmp_pos - cur_pos;
 
 #if ENABLE_FAKE_ANCHOR
-      if (chr_len > 0)
+      if (fake_anchor && chr_len > 0)
 	{
 	  const char *raw_url;
 	  /*
@@ -694,6 +680,32 @@ parse_text(ElementHandler *handler, void *context, const char *text, int len)
 }
 
 
+/*
+ * (SAX)HTMLѡ
+ * textĹlenʸHTMLʸȻפäƲϤΤΤentity
+ * ȤΤ褦ʤΡơʳʸΤ줾ˤĤơб
+ * callbackƤӽФ
+ *
+ * callbackNULLξ硢ʲ˼褦ʥǥեȤư򤹤롣
+ * startElement: ̵
+ * endElement: ̵
+ * entity: ơ֥ʸѴcharactersϥɥƤ֡
+ * characters: ̵
+ *
+ * converter0ξ硢callbackƤiconvȤäʸencoding
+ * Ѵ롣converter0ξ硢textUTF-8 encodingǤȲꤹ롣
+ *
+ * '<'⤷'&'줿ˤؤ餺б'>'';'ʤä硢
+ * '<'⤷'&'ľޤǤǥѡ󥰤ߤΥݥ󥿤֤
+ *ʳξˤNULL֤
+ */
+const char *
+parse_text(ElementHandler *handler, void *context, const char *text, int len)
+{
+  return parse_text_internal(handler, context, text, len, TRUE);
+}
+
+
 #define MAX_ATTRIBUTES	8
 /*
  * head򥿥ȸʤƲϤޤϤǤŬʥϥɥƤӡ
@@ -859,43 +871,40 @@ process_entity_ref(ElementHandler *handler, void *context, const char *head,
   if (len >= 2 && head[1] != '#')
     { /* character entity references */
       size = 0;
-      ref_tail = &head[1];
+      ref_tail = head + 1;
       do
 	{
-	  char c = *ref_tail;
-	  if (!isalnum(c))
+	  if (!isalnum(*ref_tail))
 	    break;
 	  size++;
 	  ref_tail++;
-	} while (size + 2 < len);
+	} while (size + 1 < len);
     }
   else if (len >= 4 && (head[2] == 'x' || head[2] == 'X'))
     {
       /* numeric character references(16ɽ) */
       size = 2;
-      ref_tail = &head[3];
+      ref_tail = head + 3;
       do
 	{
-	  char c = *ref_tail;
-	  if (!isxdigit(c))
+	  if (!isxdigit(*ref_tail))
 	    break;
 	  size++;
 	  ref_tail++;
-	} while (size + 4 < len);
+	} while (size + 3 < len);
     }
   else if (len >= 3)
     {
       /* numeric character references(10ɽ) */
       size = 1;
-      ref_tail = &head[2];
+      ref_tail = head + 2;
       do
 	{
-	  char c = *ref_tail;
-	  if (!isdigit(c))
+	  if (!isdigit(*ref_tail))
 	    break;
 	  size++;
 	  ref_tail++;
-	} while (size + 3 < len);
+	} while (size + 2 < len);
     }
   else
     return NULL;	/* ¿ʬ */
@@ -910,7 +919,7 @@ process_entity_ref(ElementHandler *handler, void *context, const char *head,
     }
 
 #if DEBUG_PARSER_MOST
-  fprintf(stderr, "size = %d, entity = '%s'\n", size, entity);
+  fprintf(stderr, "len=%d, size=%d, entity='%s'\n", len, size, entity);
 #endif
 
   if (handler->entityReference != NULL)
@@ -1176,17 +1185,17 @@ simple_string_canon(const char *src, int len,
   cur_pos = src;
   while (cur_pos != NULL && chars_left > 0)
     {
-      const char *tmp_pos = parse_text(&handler, &context,
-				       cur_pos, chars_left);
+      const char *tmp_pos = parse_text_internal(&handler, &context,
+						cur_pos, chars_left, FALSE);
       chars_left -= tmp_pos - cur_pos;
       if (tmp_pos == NULL)
 	break;
 
       cur_pos = tmp_pos;
       if (*cur_pos == '&')
-	parse_text(&handler, &context, "&amp;", 5);
+	parse_text_internal(&handler, &context, "&amp;", 5, FALSE);
       else if (*cur_pos == '<')
-	parse_text(&handler, &context, "&lt;", 4);
+	parse_text_internal(&handler, &context, "&lt;", 4, FALSE);
       else
 	break;	/*  */
       cur_pos++;
