@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.15 2003/11/30 19:32:34 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.16 2003/12/08 02:29:45 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -100,7 +100,7 @@ struct _OchushaBBSThreadClass
 					OchushaNetworkBrokerCacheMode mode);
   gboolean (*parse_responses)(OchushaBBSThread *thread,
 			      OchushaAsyncBuffer *buffer,
-			      int start, int number,
+			      int start, int number, gboolean no_wait,
 			      StartThreadCallback *start_thread_callback,
 			      EachResponseCallback *each_response_callback,
 			      BrokenResponseCallback *broken_response_callback,
@@ -179,6 +179,7 @@ iconv_helper *ochusha_bbs_thread_get_response_iconv_helper(
 gboolean ochusha_bbs_thread_parse_responses(OchushaBBSThread *thread,
 					    OchushaAsyncBuffer *buffer,
 					    int start, int number,
+					    gboolean no_wait,
 					    StartThreadCallback *start_cb,
 					    EachResponseCallback *response_cb,
 					    BrokenResponseCallback *broken_cb,
