@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.2 2003/12/02 13:11:43 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.3 2003/12/07 16:57:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -40,26 +40,11 @@
 #include <glib-object.h>
 #include <glib.h>
 
-#if ENABLE_REGEXP
-# if HAVE_ONIGURUMA
-#  if HAVE_ONIG_ONIGPOSIX_H
-#    include <onig/onigposix.h>
-#  elif HAVE_ONIGPOSIX_H
-#    include <onigposix.h>
-#  else
-#    error "Use of oniguruma without onig/onigposix.h header isn't considered."
-#  endif
+#if ENABLE_ONIGURUMA
+# if HAVE_ONIG_ONIGPOSIX_H
+#  include <onig/onigposix.h>
 # else
-#  if HAVE_POSIX_REGEX
-#    if HAVE_SYS_TYPES_H
-#      include <sys/types.h>
-#    endif
-#    if HAVE_REGEX_H
-#      include <regex.h>
-#    else
-#      warning "I don't know suitable header file of your posix regex library."
-#    endif
-#  endif
+#  include <onigposix.h>
 # endif
 #endif
 
@@ -926,7 +911,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 }
 
 
-#if defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA)
+#if defined(ENABLE_ONIGURUMA)
 /*
  * refresh_threadlist_by_subback_html:
  *
@@ -1170,7 +1155,7 @@ ochusha_board_jbbs_refresh_threadlist(OchushaBulletinBoard *board,
 				      EachThreadCallback *each_thread_cb,
 				      gpointer callback_data)
 {
-#if defined(ENABLE_REGEXP) && defined(HAVE_ONIGURUMA)
+#if defined(ENABLE_ONIGURUMA)
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_MITINOKU:
