@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.25 2003/12/04 08:52:21 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.27 2003/12/08 05:01:06 fuyu Exp $
  */
 
 #include "config.h"
@@ -67,7 +67,7 @@
 #define HEADER_BUFFER_LENGTH	256
 #define LOG_MESSAGE_SIZE	4096
 
-#define POLLING_INTERVAL_MILLIS	20
+#define POLLING_INTERVAL_MILLIS	100
 
 
 #define DEBUG_NETWORK		0
@@ -588,11 +588,13 @@ ochusha_network_broker_worker_sync_object_free(WorkerSyncObject *sync_object)
 static gboolean
 timeout_cb(WorkerSyncObject *sync_object)
 {
+  gboolean finished;
 #if DEBUG_NETWORK
   fprintf(stderr, "entering: timeout_cb(%p)\n", sync_object);
 #endif
 
   LOCK_WORKER_SYNC_OBJECT(sync_object);
+  finished = sync_object->finished;
   if (pthread_cond_signal(&sync_object->cond) != 0)
     {
       fprintf(stderr, "Couldn't signal a condition.\n");
@@ -604,7 +606,7 @@ timeout_cb(WorkerSyncObject *sync_object)
   fprintf(stderr, "leaving: timeout_cb(%p)\n", sync_object);
 #endif
 
-  if (!sync_object->finished)
+  if (!finished)
     return TRUE;
 
   ochusha_network_broker_worker_sync_object_free(sync_object);
@@ -621,22 +623,6 @@ poll_cb(GIOChannel *channel, GIOCondition condition,
   fprintf(stderr, "entering: poll_cb(%p)\n", sync_object);
 #endif
 
-  if (sync_object->finished)
-    {
-      /* ͭʤĤġġ
-       * ⤷줬ȺǰΥǤϡsync_objectäƤ롣
-       * ϡg_assert(!sync_object->finished);
-       * ˤ餤GLibοͤˤ狼ʤ
-       */
-#if DEBUG_NETWORK
-      fprintf(stderr, "unexpected poll_cb() called.\n");
-#endif
-      return TRUE;	/* poll_cbϿΤϤޤǤ
-			 * ͥåȥ󥰥åɡ
-			 * ºݤϡϿƤϤ
-			 */
-    }
-
   LOCK_WORKER_SYNC_OBJECT(sync_object);
   if (condition & (G_IO_IN | G_IO_PRI))
     sync_object->read_ok = TRUE;
@@ -646,13 +632,14 @@ poll_cb(GIOChannel *channel, GIOCondition condition,
       fprintf(stderr, "Couldn't signal a condition.\n");
       abort();
     }
+  sync_object->poll_id = 0;
   UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
 #if DEBUG_NETWORK
   fprintf(stderr, "leaving: poll_cb(%p)\n", sync_object);
 #endif
 
-  return TRUE;
+  return FALSE;
 }
 
 
@@ -675,20 +662,6 @@ register_polling_function_for_read(WorkerSyncObject *sync_object, int fd)
 }
 
 
-static void
-unregister_polling_function(WorkerSyncObject *sync_object)
-{
-  LOCK_WORKER_SYNC_OBJECT(sync_object);
-  if (sync_object->poll_id != 0)
-    {
-      g_source_remove(sync_object->poll_id);
-      sync_object->poll_id = 0;
-    }
-  sync_object->read_ok = FALSE;
-  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
-}
-
-
 static gboolean
 http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 {
@@ -783,14 +756,8 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
       current_status = ghttp_get_status(request);
 
-      if (sock_fd == -1 && current_status.proc > ghttp_proc_request)
-	{
-	  sock_fd = ghttp_get_socket(request);
-	  if (sock_fd > 0)
-	    register_polling_function_for_read(sync_object, sock_fd);
-	}
-      else if (current_status.proc == ghttp_proc_response
-	       || (sock_fd > 0 && current_status.proc == ghttp_proc_none))
+      if (current_status.proc == ghttp_proc_response
+	  || (sock_fd > 0 && current_status.proc == ghttp_proc_none))
 	{
 	  status_code = ghttp_status_code(request);
 	  status->status_code = status_code;
@@ -806,8 +773,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 		  else
 		    status->date = NULL;
 
-		  unregister_polling_function(sync_object);
-
 		  LOCK_WORKER_SYNC_OBJECT(sync_object);
 		  sync_object->finished = TRUE;
 		  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
@@ -821,8 +786,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
 		  return FALSE;
 		}
-
-	      unregister_polling_function(sync_object);
 	      goto error_exit;
 	    }
 	}
@@ -835,7 +798,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
       else if (state == ghttp_error)
 	{
 	  error_message = _("Unknown I/O error.");
-	  unregister_polling_function(sync_object);
 	  goto error_exit;
 	}
 
@@ -872,7 +834,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 		  gzip_buffer = gzip_buffer_new(buffer);
 		  if (gzip_buffer == NULL)
 		    {
-		      unregister_polling_function(sync_object);
 		      error_message = _("Out of memory.");
 		      goto error_exit;
 		    }
@@ -882,7 +843,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 		  gzip_buffer = gzip_buffer_new(buffer);
 		  if (gzip_buffer == NULL)
 		    {
-		      unregister_polling_function(sync_object);
 		      error_message = _("Out of memory.");
 		      goto error_exit;
 		    }
@@ -890,7 +850,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 		  break;
 
 		case UNKNOWN_ENCODING:
-		  unregister_polling_function(sync_object);
 		  error_message = _("Unknown transfer encoding.");
 		  goto error_exit;
 
@@ -906,8 +865,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 		= gzip_buffer_append_data(gzip_buffer, body, body_len);
 	      if (result == GZIP_BUFFER_ERROR)
 		{
-		  unregister_polling_function(sync_object);
-
 		  error_message = _("Inflation failed.");
 		  gzip_buffer_free(gzip_buffer);
 
@@ -935,8 +892,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	      if (!ochusha_async_buffer_append_data(buffer, body, body_len,
 			"ochusha_network_broker.c: http_read_from_url"))
 		{	/* content_encoding == IDENTITY_ENCODING */
-		  unregister_polling_function(sync_object);
-
 		  g_signal_emit(G_OBJECT(broker),
 				broker_signals[ACCESS_TERMINATED_SIGNAL],
 				0,
@@ -966,8 +921,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	  if (!ochusha_async_buffer_signal(buffer,
 			"ochusha_network_broker.c: http_read_from_url"))
 	    {
-	      unregister_polling_function(sync_object);
-
 	      g_signal_emit(G_OBJECT(broker),
 			    broker_signals[ACCESS_TERMINATED_SIGNAL],
 			    0,
@@ -995,6 +948,13 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
       if (state == ghttp_done)
 	break;
 
+      if (current_status.proc > ghttp_proc_request)
+	{
+	  sock_fd = ghttp_get_socket(request);
+	  if (sock_fd > 0)
+	    register_polling_function_for_read(sync_object, sock_fd);
+	}
+
       LOCK_WORKER_SYNC_OBJECT(sync_object);
       if (!sync_object->read_ok
 	  && pthread_cond_wait(&sync_object->cond, &sync_object->lock) != 0)
@@ -1004,7 +964,6 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	}
       UNLOCK_WORKER_SYNC_OBJECT(sync_object);
     }
-  unregister_polling_function(sync_object);
 
   if (gzip_buffer != NULL)
     {
@@ -1402,16 +1361,10 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 	  current_status = ghttp_get_status(request);
 
-	  if (sock_fd == -1 && current_status.proc > ghttp_proc_request)
-	    {
-	      sock_fd = ghttp_get_socket(request);
-	      if (sock_fd > 0)
-		register_polling_function_for_read(sync_object, sock_fd);
-	    }
-	  else if (status_code == 0
-		   && (current_status.proc == ghttp_proc_response
-		       || (sock_fd > 0
-			   && current_status.proc == ghttp_proc_none)))
+	  if (status_code == 0
+	      && (current_status.proc == ghttp_proc_response
+		  || (sock_fd > 0
+		      && current_status.proc == ghttp_proc_none)))
 	    {
 	      /* ˤ1٤ʤϤ */
 	      status_code = ghttp_status_code(request);
@@ -1423,8 +1376,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		  else
 		    status->date = NULL;
 
-		  unregister_polling_function(sync_object);
-
 		  ochusha_async_buffer_update_length(buffer, len,
 			"ochusha_network_broker.c: try_update_cache()");
 
@@ -1447,7 +1398,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		}
 	      if (status_code != 206)
 		{
-		  unregister_polling_function(sync_object);
 		  goto cache_is_dirty;
 		}
 
@@ -1459,7 +1409,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		  gzip_buffer = gzip_buffer_new(buffer);
 		  if (gzip_buffer == NULL)
 		    {
-		      unregister_polling_function(sync_object);
 		      error_message = _("Out of memory.");
 		      goto error_exit;
 		    }
@@ -1469,7 +1418,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		  gzip_buffer = gzip_buffer_new(buffer);
 		  if (gzip_buffer == NULL)
 		    {
-		      unregister_polling_function(sync_object);
 		      error_message = _("Out of memory.");
 		      goto error_exit;
 		    }
@@ -1477,7 +1425,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		  break;
 
 		case UNKNOWN_ENCODING:
-		  unregister_polling_function(sync_object);
 		  goto cache_is_dirty;	/* ĩ */
 
 		case IDENTITY_ENCODING:
@@ -1492,7 +1439,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	    }
 	  else if (state == ghttp_error)
 	    {
-	      unregister_polling_function(sync_object);
 	      error_message = _("Unknown I/O error.");
 	      goto error_exit;
 	    }
@@ -1526,7 +1472,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		    = gzip_buffer_append_data(gzip_buffer, body, body_len);
 		  if (result == GZIP_BUFFER_ERROR)
 		    {
-		      unregister_polling_function(sync_object);
 		      error_message = _("Inflation failed.");
 		      gzip_buffer_free(gzip_buffer);
 		      goto error_exit;
@@ -1546,8 +1491,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 							 body_len,
 			      "ochusha_network_broker.c: try_update_cache()"))
 		{	/* content_encoding == IDENTITY_ENCODING */
-		  unregister_polling_function(sync_object);
-
 		  g_signal_emit(G_OBJECT(args->broker),
 				broker_signals[ACCESS_TERMINATED_SIGNAL],
 				0,
@@ -1587,7 +1530,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 			     (char *)buffer->buffer + offset,
 			     CACHE_COMPARE_SIZE) != 0)
 		    {
-		      unregister_polling_function(sync_object);
 		      goto cache_is_dirty;	/* åäƤ */
 		    }
 		  else
@@ -1599,8 +1541,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	      if (!ochusha_async_buffer_signal(buffer,
 			"ochusha_network_broker.c: try_update_cache()"))
 		{
-		  unregister_polling_function(sync_object);
-
 		  g_signal_emit(G_OBJECT(args->broker),
 				broker_signals[ACCESS_TERMINATED_SIGNAL],
 				0,
@@ -1632,6 +1572,13 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  if (state == ghttp_done)
 	    break;
 
+	  if (current_status.proc > ghttp_proc_request)
+	    {
+	      sock_fd = ghttp_get_socket(request);
+	      if (sock_fd > 0)
+		register_polling_function_for_read(sync_object, sock_fd);
+	    }
+
 	  LOCK_WORKER_SYNC_OBJECT(sync_object);
 	  if (!sync_object->read_ok
 	      && pthread_cond_wait(&sync_object->cond,
@@ -1642,7 +1589,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	    }
 	  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 	}
-      unregister_polling_function(sync_object);
 
       if (buffer->length < len)
 	goto cache_is_dirty;	/* ͽǡʤäΤ
@@ -1678,7 +1624,6 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY;
       if (request != NULL)
 	{
-	  unregister_polling_function(sync_object);
 	  ghttp_request_destroy(request);
 	  args->request = NULL;
 	}
