@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_private.h,v 1.6 2003/11/23 22:37:58 fuyu Exp $
+ * $Id: ochusha_private.h,v 1.9 2003/11/26 06:43:43 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_PRIVATE_H_
@@ -141,6 +141,19 @@ trace_g_strndup(const gchar *string, int len, char *file, int line)
 #define G_STRNDUP(string, len)	trace_g_strndup(string, len, __FILE__, __LINE__)
 
 
+static inline gpointer
+trace_g_memdup(gconst pointer, int len, char *file, int line)
+{
+  char where[1024];
+  gpointer result = g_memdup(pointer, len);
+  snprintf(where, 1024, "g_memdup(%p, %d) returns %p at %s, line %d",
+	   pointer, len, result, file, line);
+  register_pointer(result, where);
+  return result;
+}
+#define G_MEMDUP(pointer, len)	trace_g_memdup(pointer, len, __FILE__, __LINE__)
+
+
 static inline void
 trace_g_free(gpointer pointer, char *file, int line)
 {
@@ -160,6 +173,7 @@ trace_g_free(gpointer pointer, char *file, int line)
 #define G_NEW0(struct_type, n_structs)	g_new0(struct_type, n_structs)
 #define G_STRDUP(string)		g_strdup(string)
 #define G_STRNDUP(string, len)		g_strndup(string, len)
+#define G_MEMDUP(pointer, len)		g_memdup(pointer, len)
 #define G_FREE(pointer)			g_free(pointer)
 #endif
 
