@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.33 2003/11/30 19:32:34 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.36 2003/12/08 14:29:35 fuyu Exp $
  */
 
 #include "config.h"
@@ -47,7 +47,7 @@
 #define DEBUG_DAT	0
 #define DEBUG_DAT_MOST	0
 
-#define ANALYSIS_INTERVAL	20
+#define ANALYSIS_INTERVAL	100
 
 
 static void ochusha_thread_2ch_class_init(OchushaThread2chClass *klass);
@@ -78,6 +78,7 @@ static OchushaAsyncBuffer *ochusha_thread_2ch_get_responses_source(
 static gboolean ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 						   OchushaAsyncBuffer *buffer,
 						   int start, int number,
+						   gboolean no_wait,
 						   StartThreadCallback *st_cb,
 						   EachResponseCallback *r_cb,
 						   BrokenResponseCallback *bcb,
@@ -680,7 +681,7 @@ extract_2ch_response(char *start_pos, char *eol_pos,
 static gboolean
 ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 				   OchushaAsyncBuffer *buffer,
-				   int start, int number,
+				   int start, int number, gboolean no_wait,
 				   StartThreadCallback *start_thread_cb,
 				   EachResponseCallback *each_response_cb,
 				   BrokenResponseCallback *broken_response_cb,
@@ -888,21 +889,23 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	if (buffer_fixed)
 	  break;
 
-	/*
-	 * XXX: ͥåȥ󥰥åɤĥäƤʤȤˤwaitʤ
-	 *      褦ˤ٤
-	 */
-	if (interval > 0
-	    || ochusha_async_buffer_is_busy(buffer,
-					    "ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses"))
-	  if (!ochusha_async_buffer_wait(buffer, "ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses"))
-	    {
-	      /* bufferϤ޲٤callerˤޤ */
-#if DEBUG_ASYNC_BUFFER_MOST
-	      fprintf(stderr, "ochusha_thread_2ch_parse_responses(): buffer has been terminated.\n");
-#endif
+	if (interval > 0)
+	  {
+	    if (no_wait)
 	      break;
-	    }
+	    if (ochusha_async_buffer_is_busy(buffer,
+		"ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses")
+		&& !ochusha_async_buffer_wait(buffer,
+		"ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses"))
+	      {
+		/* bufferϤ޲٤callerˤޤ */
+#if DEBUG_ASYNC_BUFFER_MOST
+		fprintf(stderr, "ochusha_thread_2ch_parse_responses(): buffer has been terminated.\n");
+#endif
+		break;
+	      }
+	    interval = ANALYSIS_INTERVAL;
+	  }
 
 	if (status->state
 	    == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
@@ -1050,7 +1053,10 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   const char *bbs;
   const char *key;
   char *query = NULL;
-  time_t time;
+  long time;	/* time_tˤ٤10ʿʸؤѴ
+		 * ԤˡʤΤǡ褺longѴƤޤ
+		 * long32bitʥƥˤ2038ǯ()¸ߤ롣
+		 */
   iconv_t converter;
   OchushaUtils2chPostResult post_result;
 
