@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.3 2003/12/02 13:11:43 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.6 2003/12/08 14:29:35 fuyu Exp $
  */
 
 #include "config.h"
@@ -48,27 +48,22 @@
 #include <unistd.h>
 
 
-#if ENABLE_REGEXP
-# if HAVE_ONIGURUMA
-#  if HAVE_ONIG_ONIGURUMA_H
-#    include <onig/oniguruma.h>
-#    define ENABLE_HTML_TO_DAT_CONVERTER	1
-#  elif HAVE_ONIGURUMA_H
-#    include <oniguruma.h>
-#    define ENABLE_HTML_TO_DAT_CONVERTER	1
-#  else
-#    error "Use of oniguruma without oniguruma.h header isn't considered."
-#  endif
+#if ENABLE_ONIGURUMA
+# if HAVE_ONIG_ONIGURUMA_H
+#  include <onig/oniguruma.h>
 # else
-#    define ENABLE_HTML_TO_DAT_CONVERTER	0
-# endif	/* HAVE_ONIGURUMA */
-#endif	/* HAVE_REGEXP */
+#  include <oniguruma.h>
+# endif
+# define ENABLE_HTML_TO_DAT_CONVERTER	1
+#else
+# define ENABLE_HTML_TO_DAT_CONVERTER	0
+#endif
 
 
 #define DEBUG_DAT	0
 #define DEBUG_DAT_MOST	0
 
-#define ANALYSIS_INTERVAL	20
+#define ANALYSIS_INTERVAL	100
 
 
 static void ochusha_thread_jbbs_class_init(OchushaThreadJBBSClass *klass);
@@ -81,13 +76,14 @@ static OchushaAsyncBuffer *ochusha_thread_jbbs_get_responses_source(
 					OchushaNetworkBroker *broker,
 					OchushaNetworkBrokerCacheMode mode);
 static gboolean ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
-						   OchushaAsyncBuffer *buffer,
-						   int start, int number,
-						   StartThreadCallback *st_cb,
-						   EachResponseCallback *r_cb,
-						   BrokenResponseCallback *bcb,
-						   EndThreadCallback *end_cb,
-						   gpointer callback_data);
+						    OchushaAsyncBuffer *buffer,
+						    int start, int number,
+						    gboolean no_wait,
+						    StartThreadCallback *st_cb,
+						    EachResponseCallback *r_cb,
+						    BrokenResponseCallback *bcb,
+						    EndThreadCallback *end_cb,
+						    gpointer callback_data);
 static const char *ochusha_thread_jbbs_get_base_url(OchushaBBSThread *thread);
 
 static gboolean ochusha_thread_jbbs_preview_response(OchushaBBSThread *thread,
@@ -457,13 +453,13 @@ extract_jbbs_response(char *start_pos, char *eol_pos,
  */
 static gboolean
 ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
-				   OchushaAsyncBuffer *buffer,
-				   int start, int number,
-				   StartThreadCallback *start_thread_cb,
-				   EachResponseCallback *each_response_cb,
-				   BrokenResponseCallback *broken_response_cb,
-				   EndThreadCallback *end_thread_cb,
-				   gpointer callback_data)
+				    OchushaAsyncBuffer *buffer,
+				    int start, int number, gboolean no_wait,
+				    StartThreadCallback *start_thread_cb,
+				    EachResponseCallback *each_response_cb,
+				    BrokenResponseCallback *broken_response_cb,
+				    EndThreadCallback *end_thread_cb,
+				    gpointer callback_data)
 {
   OchushaThread2ch *thread_2ch;
   unsigned int *responses;
@@ -486,7 +482,8 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
       status = &fake_status;
     }
 
-  if (!ochusha_async_buffer_active_ref(buffer, "ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses"))
+  if (!ochusha_async_buffer_active_ref(buffer,
+		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses"))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
       fprintf(stderr, "buffer has been terminated.\n");
@@ -663,17 +660,23 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	 * XXX: ͥåȥ󥰥åɤĥäƤʤȤˤwaitʤ
 	 *      褦ˤ٤
 	 */
-	if (interval > 0
-	    || ochusha_async_buffer_is_busy(buffer,
-					    "ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses"))
-	  if (!ochusha_async_buffer_wait(buffer, "ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses"))
-	    {
-	      /* bufferϤ޲٤callerˤޤ */
-#if DEBUG_ASYNC_BUFFER_MOST
-	      fprintf(stderr, "ochusha_thread_jbbs_parse_responses(): buffer has been terminated.\n");
-#endif
+	if (interval > 0)
+	  {
+	    if (no_wait)
 	      break;
-	    }
+	    if (ochusha_async_buffer_is_busy(buffer,
+		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses")
+		&& !ochusha_async_buffer_wait(buffer,
+		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses"))
+	      {
+		/* bufferϤ޲٤callerˤޤ */
+#if DEBUG_ASYNC_BUFFER_MOST
+		fprintf(stderr, "ochusha_thread_jbbs_parse_responses(): buffer has been terminated.\n");
+#endif
+		break;
+	      }
+	    interval = ANALYSIS_INTERVAL;
+	  }
 
 	if (status->state
 	    == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
@@ -703,7 +706,8 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
       thread_2ch->date = G_STRDUP(status->date);
     }
 
-  ochusha_async_buffer_active_unref(buffer, "ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses");
+  ochusha_async_buffer_active_unref(buffer,
+		"ochusha_thread_jbbs.c: ochusha_thread_jbbs_parse_responses");
 
   if (end_thread_cb != NULL)
     result = (*end_thread_cb)(thread, TRUE, callback_data);
@@ -1656,6 +1660,7 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
 
   return dat_buffer;
 #else
+  fprintf(stderr, "Oniguruma required.\n");
   return NULL;
 #endif	/* ENABLE_HTML_TO_DAT_CONVERTER */
 }
